==> qtjambi-websockets-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiWebSockets/QWebSocketCorsAuthenticator_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebSockets/qwebsocketcorsauthenticator.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebSocketCorsAuthenticator(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebSocketCorsAuthenticator")
    QWebSocketCorsAuthenticator *_ptr = reinterpret_cast<QWebSocketCorsAuthenticator *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWebSocketCorsAuthenticator(QString)
void __qt_construct_QWebSocketCorsAuthenticator_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebSocketCorsAuthenticator(QString)")
    jstring origin0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_origin0 = qtjambi_cast<QString >(__jni_env, origin0);
    QWebSocketCorsAuthenticator *__qt_this = new(__qtjambi_ptr) QWebSocketCorsAuthenticator(__qt_origin0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QWebSocketCorsAuthenticator(QWebSocketCorsAuthenticator)
void __qt_construct_QWebSocketCorsAuthenticator_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebSocketCorsAuthenticator(QWebSocketCorsAuthenticator)")
    jobject other0 = __java_arguments[0].l;
    const QWebSocketCorsAuthenticator& __qt_other0 = qtjambi_cast<const QWebSocketCorsAuthenticator& >(__jni_env, other0);
    QWebSocketCorsAuthenticator *__qt_this = new(__qtjambi_ptr) QWebSocketCorsAuthenticator(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QWebSocketCorsAuthenticator
void __qt_destruct_QWebSocketCorsAuthenticator(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWebSocketCorsAuthenticator")
    reinterpret_cast<QWebSocketCorsAuthenticator*>(ptr)->~QWebSocketCorsAuthenticator();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWebSocketCorsAuthenticator::QWebSocketCorsAuthenticator(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketCorsAuthenticator_initialize_1native__Lio_qt_websockets_QWebSocketCorsAuthenticator_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring origin0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebSocketCorsAuthenticator::QWebSocketCorsAuthenticator(QString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = origin0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebSocketCorsAuthenticator_0, sizeof(QWebSocketCorsAuthenticator), typeid(QWebSocketCorsAuthenticator), false, &deleter_QWebSocketCorsAuthenticator, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebSocketCorsAuthenticator::QWebSocketCorsAuthenticator(QWebSocketCorsAuthenticator)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketCorsAuthenticator_initialize_1native__Lio_qt_websockets_QWebSocketCorsAuthenticator_2Lio_qt_websockets_QWebSocketCorsAuthenticator_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebSocketCorsAuthenticator::QWebSocketCorsAuthenticator(QWebSocketCorsAuthenticator)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebSocketCorsAuthenticator_1, sizeof(QWebSocketCorsAuthenticator), typeid(QWebSocketCorsAuthenticator), false, &deleter_QWebSocketCorsAuthenticator, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebSocketCorsAuthenticator::allowed()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketCorsAuthenticator_allowed_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWebSocketCorsAuthenticator *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketCorsAuthenticator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketCorsAuthenticator::allowed()const", __qt_this)
        __java_return_value = __qt_this->allowed();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebSocketCorsAuthenticator::operator=(QWebSocketCorsAuthenticator)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketCorsAuthenticator_assign_1native_1cref_1QWebSocketCorsAuthenticator__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebSocketCorsAuthenticator *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketCorsAuthenticator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketCorsAuthenticator::operator=(QWebSocketCorsAuthenticator)", __qt_this)
        const QWebSocketCorsAuthenticator& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QWebSocketCorsAuthenticator>(__jni_env, other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebSocketCorsAuthenticator::origin()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketCorsAuthenticator_origin_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWebSocketCorsAuthenticator *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketCorsAuthenticator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketCorsAuthenticator::origin()const", __qt_this)
        QString __qt_return_value = __qt_this->origin();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebSocketCorsAuthenticator::setAllowed(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketCorsAuthenticator_setAllowed_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean allowed0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebSocketCorsAuthenticator *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketCorsAuthenticator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketCorsAuthenticator::setAllowed(bool)", __qt_this)
        __qt_this->setAllowed(static_cast<bool>(allowed0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebSocketCorsAuthenticator::swap(QWebSocketCorsAuthenticator&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketCorsAuthenticator_swap_1native_1ref_1QWebSocketCorsAuthenticator__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebSocketCorsAuthenticator *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketCorsAuthenticator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketCorsAuthenticator::swap(QWebSocketCorsAuthenticator&)", __qt_this)
        QWebSocketCorsAuthenticator& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QWebSocketCorsAuthenticator>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeCustomStructors)
void* custom_constructor_QWebSocketCorsAuthenticator(void* placement, const void * __in_var)
{
    Q_UNUSED(placement)
    const QWebSocketCorsAuthenticator* copy = static_cast<const QWebSocketCorsAuthenticator*>(__in_var);
    Q_UNUSED(copy)
    if(copy){
        return new(placement) QWebSocketCorsAuthenticator(*copy);
    }else{
        return new(placement) QWebSocketCorsAuthenticator("");
    }
}
// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketCorsAuthenticator_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebSocketCorsAuthenticator *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketCorsAuthenticator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebSocketCorsAuthenticator(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QWebSocketCorsAuthenticator>("QWebSocketCorsAuthenticator", "io/qt/websockets/QWebSocketCorsAuthenticator");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWebSocketCorsAuthenticator, {
        ConstructorInfo(&__qt_construct_QWebSocketCorsAuthenticator_0, "Ljava/lang/String;")
       ,ConstructorInfo(&__qt_construct_QWebSocketCorsAuthenticator_1, "Lio/qt/websockets/QWebSocketCorsAuthenticator;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebSocketCorsAuthenticator);
    registerMetaType<QWebSocketCorsAuthenticator>("QWebSocketCorsAuthenticator", &custom_constructor_QWebSocketCorsAuthenticator);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-websockets-debuginfo-windows-x64-5.15.20.jar: sources/QtJambiWebSockets/QWebSocketCorsAuthenticator_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebSockets/qwebsocketcorsauthenticator.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebSocketCorsAuthenticator(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebSocketCorsAuthenticator")
    QWebSocketCorsAuthenticator *_ptr = reinterpret_cast<QWebSocketCorsAuthenticator *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWebSocketCorsAuthenticator(QString)
void __qt_construct_QWebSocketCorsAuthenticator_cref_QString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebSocketCorsAuthenticator(QString)")
    jstring origin0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_origin0 = qtjambi_cast<QString>(__jni_env, origin0);
    QWebSocketCorsAuthenticator *__qt_this = new(__qtjambi_ptr) QWebSocketCorsAuthenticator(__qt_origin0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QWebSocketCorsAuthenticator::QWebSocketCorsAuthenticator(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketCorsAuthenticator_initialize_1native__Lio_qt_websockets_QWebSocketCorsAuthenticator_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring origin0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebSocketCorsAuthenticator::QWebSocketCorsAuthenticator(QString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = origin0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebSocketCorsAuthenticator_cref_QString, sizeof(QWebSocketCorsAuthenticator), typeid(QWebSocketCorsAuthenticator), false, &deleter_QWebSocketCorsAuthenticator, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QWebSocketCorsAuthenticator(QWebSocketCorsAuthenticator)
void __qt_construct_QWebSocketCorsAuthenticator_cref_QWebSocketCorsAuthenticator(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebSocketCorsAuthenticator(QWebSocketCorsAuthenticator)")
    jobject other0 = __java_arguments[0].l;
    const QWebSocketCorsAuthenticator& __qt_other0 = qtjambi_cast<const QWebSocketCorsAuthenticator& >(__jni_env, other0);
    QWebSocketCorsAuthenticator *__qt_this = new(__qtjambi_ptr) QWebSocketCorsAuthenticator(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QWebSocketCorsAuthenticator::QWebSocketCorsAuthenticator(QWebSocketCorsAuthenticator)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketCorsAuthenticator_initialize_1native__Lio_qt_websockets_QWebSocketCorsAuthenticator_2Lio_qt_websockets_QWebSocketCorsAuthenticator_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebSocketCorsAuthenticator::QWebSocketCorsAuthenticator(QWebSocketCorsAuthenticator)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebSocketCorsAuthenticator_cref_QWebSocketCorsAuthenticator, sizeof(QWebSocketCorsAuthenticator), typeid(QWebSocketCorsAuthenticator), false, &deleter_QWebSocketCorsAuthenticator, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QWebSocketCorsAuthenticator
void __qt_destruct_QWebSocketCorsAuthenticator(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWebSocketCorsAuthenticator")
    reinterpret_cast<QWebSocketCorsAuthenticator*>(ptr)->~QWebSocketCorsAuthenticator();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWebSocketCorsAuthenticator::allowed()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketCorsAuthenticator_allowed_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWebSocketCorsAuthenticator *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketCorsAuthenticator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketCorsAuthenticator::allowed()const", __qt_this)
        __java_return_value = __qt_this->allowed();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebSocketCorsAuthenticator::operator=(QWebSocketCorsAuthenticator)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketCorsAuthenticator_assign_1native_1cref_1QWebSocketCorsAuthenticator__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebSocketCorsAuthenticator *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketCorsAuthenticator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketCorsAuthenticator::operator=(QWebSocketCorsAuthenticator)", __qt_this)
        const QWebSocketCorsAuthenticator& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QWebSocketCorsAuthenticator>(__jni_env, other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebSocketCorsAuthenticator::origin()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketCorsAuthenticator_origin_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWebSocketCorsAuthenticator *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketCorsAuthenticator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketCorsAuthenticator::origin()const", __qt_this)
        QString __qt_return_value = __qt_this->origin();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebSocketCorsAuthenticator::setAllowed(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketCorsAuthenticator_setAllowed_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean allowed0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebSocketCorsAuthenticator *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketCorsAuthenticator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketCorsAuthenticator::setAllowed(bool)", __qt_this)
        __qt_this->setAllowed(static_cast<bool>(allowed0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebSocketCorsAuthenticator::swap(QWebSocketCorsAuthenticator&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketCorsAuthenticator_swap_1native_1ref_1QWebSocketCorsAuthenticator__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebSocketCorsAuthenticator *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketCorsAuthenticator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebSocketCorsAuthenticator::swap(QWebSocketCorsAuthenticator&)", __qt_this)
        QWebSocketCorsAuthenticator& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QWebSocketCorsAuthenticator>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeCustomStructors)
void* custom_constructor_QWebSocketCorsAuthenticator(void* placement, const void * __in_var)
{
    Q_UNUSED(placement)
    const QWebSocketCorsAuthenticator* copy = static_cast<const QWebSocketCorsAuthenticator*>(__in_var);
    Q_UNUSED(copy)
    if(copy){
        return new(placement) QWebSocketCorsAuthenticator(*copy);
    }else{
        return new(placement) QWebSocketCorsAuthenticator("");
    }
}
// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_websockets_QWebSocketCorsAuthenticator_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebSocketCorsAuthenticator *__qt_this = QtJambiAPI::objectFromNativeId<QWebSocketCorsAuthenticator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebSocketCorsAuthenticator(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QWebSocketCorsAuthenticator>("QWebSocketCorsAuthenticator", "io/qt/websockets/QWebSocketCorsAuthenticator");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWebSocketCorsAuthenticator, {
        ConstructorInfo(&__qt_construct_QWebSocketCorsAuthenticator_cref_QString, "Ljava/lang/String;")
       ,ConstructorInfo(&__qt_construct_QWebSocketCorsAuthenticator_cref_QWebSocketCorsAuthenticator, "Lio/qt/websockets/QWebSocketCorsAuthenticator;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebSocketCorsAuthenticator);
    registerMetaType<QWebSocketCorsAuthenticator>("QWebSocketCorsAuthenticator", &custom_constructor_QWebSocketCorsAuthenticator);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
